@@ -15,7 +15,7 @@ subroutine ll2k_diff(n, obsImg, bandwidth, diff)
 
   integer :: i, j, n, i1, j1, k, bandwidth
   
-  double precision :: z(0:600, 0:600), z1(0:600, 0:600), x, y, temp, &
+  double precision :: z(0:n, 0:n), z1(0:(n+2*bandwidth), 0:(n+2*bandwidth)), x, y, temp, &
        x1, y1, ker, r00, r20, bhat, chat, bb, ra, fhat1, fhat2, ker1, &
        gradperp, u00, u01, u10, u20, u02, u11, obsImg(0:n, 0:n), &
        den1, den2, v00, v01, v10, v20, v02, v11, Au1, Au2, Au3, Av1, &
@@ -41,7 +41,7 @@ subroutine ll2k_diff(n, obsImg, bandwidth, diff)
 
   ! Extend image to avoid boundary problems.
 
-  Call extend(n, k, z, z1)
+  Call extend(n, k, z, z1(0:(n+2*k), 0:(n+2*k)))
 
   ! Calculate first derivatives                       
 
